@@ -16,13 +16,12 @@ package fv_test
 
 import (
 	"context"
-	"fmt"
 	"io/ioutil"
 	"os"
 	"time"
 
+	v3 "github.com/projectcalico/api/pkg/apis/projectcalico/v3"
 	"github.com/projectcalico/libcalico-go/lib/apiconfig"
-	v3 "github.com/projectcalico/libcalico-go/lib/apis/v3"
 	"github.com/projectcalico/libcalico-go/lib/options"
 
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -59,7 +58,7 @@ var _ = Describe("KubeControllersConfiguration tests", func() {
 		var err error
 		kconfigFile, err = ioutil.TempFile("", "ginkgo-nodecontroller")
 		Expect(err).NotTo(HaveOccurred())
-		data := fmt.Sprintf(testutils.KubeconfigTemplate, apiserver.IP)
+		data := testutils.BuildKubeconfig(apiserver.IP)
 		_, err = kconfigFile.Write([]byte(data))
 		Expect(err).NotTo(HaveOccurred())
 
@@ -71,13 +70,13 @@ var _ = Describe("KubeControllersConfiguration tests", func() {
 
 		// Wait for the apiserver to be available.
 		Eventually(func() error {
-			_, err := k8sClient.CoreV1().Namespaces().List(metav1.ListOptions{})
+			_, err := k8sClient.CoreV1().Namespaces().List(context.Background(), metav1.ListOptions{})
 			return err
 		}, 30*time.Second, 1*time.Second).Should(BeNil())
 
 		// Run controller manager.  Empirically it can take around 10s until the
 		// controller manager is ready to create default service accounts, even
-		// when the hyperkube image has already been downloaded to run the API
+		// when the k8s image has already been downloaded to run the API
 		// server.  We use Eventually to allow for possible delay when doing
 		// initial pod creation below.
 		controllerManager = testutils.RunK8sControllerManager(apiserver.IP)
@@ -230,9 +229,9 @@ var _ = Describe("KubeControllersConfiguration tests", func() {
 				return kcc.Status.EnvironmentVars
 			}, time.Second*10, time.Millisecond*500).Should(Equal(map[string]string{"ENABLED_CONTROLLERS": "node"}))
 
-			// set node & policy controller to enabled on API
-			kcc.Spec.Controllers.Node = &v3.NodeControllerConfig{}
+			// Enable the policy controller, which isn't specified in the ENABLED_CONTROLLERS env.
 			kcc.Spec.Controllers.Policy = &v3.PolicyControllerConfig{}
+
 			// Also delete the status so we can see it is reset
 			kcc.Status = v3.KubeControllersConfigurationStatus{}
 			var err error
@@ -243,7 +242,7 @@ var _ = Describe("KubeControllersConfiguration tests", func() {
 			// the controller should not restart
 			Consistently(uut.Stopped, time.Second*10, time.Millisecond*500).Should(BeFalse())
 
-			// Should have recreated status
+			// Should have recreated status with only the node controller enabled.
 			kcc, err = c.KubeControllersConfiguration().Get(context.Background(), "default", options.GetOptions{})
 			Expect(err).ToNot(HaveOccurred())
 			Expect(kcc.Status.EnvironmentVars).To(Equal(map[string]string{"ENABLED_CONTROLLERS": "node"}))
